@@ -142,7 +142,7 @@ class piplyr:
     
 # mutate a new column based on an expression
    
-    def mutate(self, expression,new_var_name):
+    def mutate_eval(self, expression,new_col):
         
         """
         This method allows you to create a new column in your dataframe by apilying an expression to existing columns.
@@ -162,10 +162,12 @@ class piplyr:
         1 2 5 7
         2 3 6 9
         """
-        self.df[new_var_name] = self.df.eval(expression,inplace=False)
+        self.df[new_col] = self.df.eval(expression,inplace=False)
         return self
     
-            
+    def mutate_func(self,col,func,new_col):
+        self.df[new_col] = func(self.df[col])
+        return self        
 # write any sql expression on the data frame fed to pilyr          
     def sql_plyr(self,expression):
         
